==> nomadic_2025_01_17.zip: nomadic/resources/views/frontend/booking/booking-form.blade.php <==
<div class="inner-border">
    <h2 id="days_hours" class="p-3 text-center" style="border-bottom:1px solid #c3c5c8;">
    @if(isset(session()->get('temp-booking-points')['studio'][session()->get('temp-booking-studio-selection')]) && $type=='studio')
        @php $studio = session()->get('temp-booking-points')['studio'][session()->get('temp-booking-studio-selection')]; $hours = 0;@endphp
        @if(isset($studio['daily'])) {{count($studio['daily'])}}D @endif
        @if(isset($studio['hourly']))
            @foreach($studio['hourly'] as $hr)
                @php
                $hourly_data = explode('|',$hr);
                $hours = $hours + $hourly_data[0];
                @endphp
            @endforeach
            {{$hours}}H
        @endif
    @endif
    @if(isset(session()->get('temp-booking-points')['equipment'][session()->get('temp-booking-equipment-selection')]) && $type=='equipment')
        @php $equipment = session()->get('temp-booking-points')['equipment'][session()->get('temp-booking-equipment-selection')]; $hours = 0;@endphp
        @if(isset($equipment['daily'])) {{count($equipment['daily'])}}D @endif
        @if(isset($equipment['hourly']))
            @foreach($equipment['hourly'] as $hr)
                @php
                $hourly_data = explode('|',$hr);
                $hours = $hours + $hourly_data[0];
                @endphp
            @endforeach
            {{$hours}}H
        @endif
    @endif
    @if(isset(session()->get('temp-booking-points')['resource'][session()->get('temp-booking-resource-selection')]) && $type=='resource')
        @php $resource = session()->get('temp-booking-points')['resource'][session()->get('temp-booking-resource-selection')]; $hours = 0;@endphp
        @if(isset($resource['daily'])) {{count($resource['daily'])}}D @endif
        @if(isset($resource['hourly']))
            @foreach($resource['hourly'] as $hr)
                @php
                $hourly_data = explode('|',$hr);
                $hours = $hours + $hourly_data[0];
                @endphp
            @endforeach
            {{$hours}}H
        @endif
    @endif
    </h2>
    <form id="bookingForm">
        @csrf
        <div class="row mt-4 ps-3 pe-3">
            <div class="col-md-12 position-relative">
                <h6 class="lblbooking">Where</h6>
                <select name="txt_location" class="form-control" @if($type!='studio' && !isset(request()->process)) disabled @endif>
                    <option value="">Location</option>
                    @foreach($locations as $key=>$val)
                    <option value="{{$key}}" @if(session()->get('booking-form.location')==$key) selected @endif>{{$val}}</option>
                    @endforeach
                </select>
                <i class="bi bi-caret-down-fill searchicon" style="top:32px;"></i>
            </div>
        </div>
        <div class="row mt-3 ps-3 pe-3">
            <div class="col-md-6">
                <h6 class="lblbooking">Start</h6>
                <input name="txt_start_date" type="date" class="form-control" value="{{session()->get('booking-form.start_date')}}" @if($type!='studio' && !isset(request()->process)) disabled @endif/>
            </div>
            <div class="col-md-6">
                <h6 class="lblbooking">&nbsp;</h6>
                <input name="txt_start_time" type="time" class="form-control" value="{{session()->get('booking-form.start_time')}}" @if($type!='studio' && !isset(request()->process)) disabled @endif/>
            </div>
        </div>
        <div class="row mt-3 ps-3 pe-3">
            <div class="col-md-6">
                <h6 class="lblbooking">End</h6>
                <input name="txt_end_date" type="date" class="form-control" value="{{session()->get('booking-form.end_date')}}" @if($type!='studio' && !isset(request()->process)) disabled @endif/>
            </div>
            <div class="col-md-6">
                <h6 class="lblbooking">&nbsp;</h6>
                <input name="txt_end_time" type="time" class="form-control" value="{{session()->get('booking-form.end_time')}}" @if($type!='studio' && !isset(request()->process)) disabled @endif/>
            </div>
        </div>
        <div class="row mt-3 ps-3 pe-3" id="txt_price_container">
        @include('frontend.booking.price-box')
        </div>
        <div class="row mt-3 mb-3 ps-3 pe-3">
            <div class="col-md-12">
                <button id="btn_booking_form" type="button" class="btn btn-primary btndisb w-100 mb-2" @if($type!='studio' && !isset(request()->process)) disabled @endif>Search </button>
                @if($type=='resource')
                <a href="{{$redirect}}" class="btn btn-primary w-100 mt-2">Confirm Booking</a>
                @else
                <a href="{{$redirect}}" class="btn2 btn-light w-100 border border-dark">Skip </a>
                <button id="btn_booking_continue" type="button" data-type="{{$type}}" data-redirect="{{$redirect}}" class="btn btn-primary w-100 mt-2">Continue</button>
                @endif
            </div>
        </div>
    </form>
</div>

==> nomadic_2025_07_19.zip: nomadic/resources/views/frontend/booking/booking-form.blade.php <==
<div class="inner-border">
    <h2 id="days_hours" class="p-3 text-center" style="border-bottom:1px solid #c3c5c8;">
    @if(isset(session()->get('temp-booking-points')['studio'][session()->get('temp-booking-studio-selection')]) && $type=='studio')
        @php $studio = session()->get('temp-booking-points')['studio'][session()->get('temp-booking-studio-selection')]; $hours = 0;@endphp
        @if(isset($studio['daily'])) {{count($studio['daily'])}}D @endif
        @if(isset($studio['hourly']))
            @foreach($studio['hourly'] as $hr)
                @php
                $hourly_data = explode('|',$hr);
                $hours = $hours + $hourly_data[0];
                @endphp
            @endforeach
            {{$hours}}H
        @endif
    @endif
    @if(isset(session()->get('temp-booking-points')['equipment'][session()->get('temp-booking-equipment-selection')]) && $type=='equipment')
        @php $equipment = session()->get('temp-booking-points')['equipment'][session()->get('temp-booking-equipment-selection')]; $hours = 0;@endphp
        @if(isset($equipment['daily'])) {{count($equipment['daily'])}}D @endif
        @if(isset($equipment['hourly']))
            @foreach($equipment['hourly'] as $hr)
                @php
                $hourly_data = explode('|',$hr);
                $hours = $hours + $hourly_data[0];
                @endphp
            @endforeach
            {{$hours}}H
        @endif
    @endif
    @if(isset(session()->get('temp-booking-points')['resource'][session()->get('temp-booking-resource-selection')]) && $type=='resource')
        @php $resource = session()->get('temp-booking-points')['resource'][session()->get('temp-booking-resource-selection')]; $hours = 0;@endphp
        @if(isset($resource['daily'])) {{count($resource['daily'])}}D @endif
        @if(isset($resource['hourly']))
            @foreach($resource['hourly'] as $hr)
                @php
                $hourly_data = explode('|',$hr);
                $hours = $hours + $hourly_data[0];
                @endphp
            @endforeach
            {{$hours}}H
        @endif
    @endif
    </h2>
    <form id="bookingForm">
        @csrf
        <input type="hidden" name="type" value="{{$type}}">
        <div class="row mt-4 ps-3 pe-3">
            <div class="col-md-12 position-relative">
                <h6 class="lblbooking">Where</h6>
                <select name="txt_location" class="form-control" @if(!$editForm) disabled @endif>
                    <option value="">Location</option>
                    @foreach($locations as $key=>$val)
                    <option value="{{$key}}" @if(session()->get('booking-form.location')==$key) selected @endif>{{$val}}</option>
                    @endforeach
                </select>
                <i class="bi bi-caret-down-fill searchicon" style="top:22px;"></i>
            </div>
        </div>
        <div class="row mt-3 ps-3 pe-3">
            <div class="col-md-6">
                <h6 class="lblbooking">Start</h6>
                <input name="txt_start_date" type="date" class="form-control" value="{{session()->get('booking-form.start_date')}}" min="{{$advance_date_flag}}" onkeydown="return false;" @if(!$editForm) disabled @endif/>
            </div>
            @php
                $startTime = session('booking-form.start_time');
                $formattedTimeStart = $startTime
                    ? \Carbon\Carbon::createFromFormat('H:i:s', $startTime)->format('h:i A')
                    : '09:00 AM'; // default value
            @endphp
            <div class="col-md-6">
                <h6 class="lblbooking">&nbsp;</h6>
                <input name="txt_start_time" type="text" class="form-control stimepickerbook" placeholder="Start time" readonly value="{{$formattedTimeStart}}" @if(!$editForm) disabled @endif/>
            </div>
        </div>
        <div class="row mt-3 ps-3 pe-3">
            <div class="col-md-6">
                <h6 class="lblbooking">End</h6>
                <input name="txt_end_date" type="date" class="form-control" value="{{session()->get('booking-form.end_date')}}" min="{{$advance_date_flag}}" onkeydown="return false;" @if(!$editForm) disabled @endif />
            </div>
            @php
                $endTime = session('booking-form.end_time');
                $formattedTimeEnd = $endTime
                    ? \Carbon\Carbon::createFromFormat('H:i:s', $endTime)->format('h:i A')
                    : '05:00 PM'; // default value
            @endphp
            <div class="col-md-6">
                <h6 class="lblbooking">&nbsp;</h6>
                <input name="txt_end_time" type="text" class="form-control etimepickerbook" placeholder="End time" readonly value="{{$formattedTimeEnd}}" @if(!$editForm) disabled @endif/>
            </div>
        </div>
        <div class="row mt-3 ps-3 pe-3" id="txt_price_container">
        @include('frontend.booking.price-box')
        </div>
        <div class="row mt-3 mb-3 ps-3 pe-3">
            <div class="col-md-12">
                <button id="btn_booking_form" type="button" class="btn btn-primary btndisb w-100 mb-2">Search </button>
                @if($type=='resource')
                <a href="{{$redirect}}" class="btn btn-primary w-100 mt-2">Review Booking</a>
                @else
                <a href="{{$redirect}}" class="btn2 btn-light w-100 border border-dark">Skip </a>
                <button id="btn_booking_continue" type="button" data-type="{{$type}}" data-redirect="{{$redirect}}" class="btn btn-primary w-100 mt-2">Continue</button>
                @endif
            </div>
        </div>
    </form>
</div>
